==> breeze_website_builder_6.5.0.tar.gz: manage/plugins/lang/gallery/af.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Bestuur Lightbox Gallary Parameters");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "bestuur Gallery");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Full-Size Image Breedte");
define('MANAGE_GALLERY_FULL_HEIGHT', "Full-Size Image Hoogte");
define('MANAGE_GALLERY_THUMB_WIDTH', "Duimnaelskets Beeld Breedte");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Duimnaelskets Image Hoogte");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Bewaar Thumb Aspek verhouding");
define('MANAGE_GALLERY_SHOW_TITLES', "Titels Wys");
define('MANAGE_GALLERY_DISABLE_SORT', "Skakel Sorteer");
define('MANAGE_GALLERY_DELETE_IMAGE', "verwyder Image");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "Slaan Sort Order");
define('MANAGE_GALLERY_PUBLISH_MSG', "Klik op &quot;Update&quot; om te publiseer <br /> jou foto beelde.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "Alle foto&#39;s is verklein en instellings is gestoor.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "Daar was &#39;n fout grootte van die beelde of spaar instellings.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "Jou beeld (s) is opgelaai.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "Daar was &#39;n fout tydens die laai van jou beeld (s).");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "Die lêer wat u probeer oplaai is nie &#39;n beeld.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "Die lêer wat u probeer oplaai is te groot.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "Die titel is gestoor.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "Is jy seker jy wil die beeld te verwyder");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "Die beeld is verwyder.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "Daar was &#39;n fout van die beeld te verwyder.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "parameters spaar en grootte van beelde, wag asseblief ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Oplaai, wag asseblief ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "Die volgorde is nie gestoor. Wil jy die volgorde te red?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "Die beeld sorteervolgorde is gestoor.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "Daar was &#39;n fout met die stoor van die beeld soort.");
?>

==> breeze_website_builder_6.6.18.tar.gz: manage/plugins/lang/gallery/af.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Bestuur Lightbox Gallary Parameters");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "bestuur Gallery");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Full-Size Image Breedte");
define('MANAGE_GALLERY_FULL_HEIGHT', "Full-Size Image Hoogte");
define('MANAGE_GALLERY_THUMB_WIDTH', "Duimnaelskets Beeld Breedte");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Duimnaelskets Image Hoogte");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Bewaar Thumb Aspek verhouding");
define('MANAGE_GALLERY_SHOW_TITLES', "Titels Wys");
define('MANAGE_GALLERY_DISABLE_SORT', "Skakel Sorteer");
define('MANAGE_GALLERY_DELETE_IMAGE', "verwyder Image");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "Slaan Sort Order");
define('MANAGE_GALLERY_PUBLISH_MSG', "Klik op &quot;Update&quot; om te publiseer <br /> jou foto beelde.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "Alle foto&#39;s is verklein en instellings is gestoor.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "Daar was &#39;n fout grootte van die beelde of spaar instellings.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "Jou beeld (s) is opgelaai.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "Daar was &#39;n fout tydens die laai van jou beeld (s).");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "Die lêer wat u probeer oplaai is nie &#39;n beeld.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "Die lêer wat u probeer oplaai is te groot.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "Die titel is gestoor.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "Is jy seker jy wil die beeld te verwyder");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "Die beeld is verwyder.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "Daar was &#39;n fout van die beeld te verwyder.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "parameters spaar en grootte van beelde, wag asseblief ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Oplaai, wag asseblief ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "Die volgorde is nie gestoor. Wil jy die volgorde te red?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "Die beeld sorteervolgorde is gestoor.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "Daar was &#39;n fout met die stoor van die beeld soort.");
define('MANAGE_GALLERY_UPLOAD_BIGGER_THAN_ALLOWED_ERR', "Die lêer wat u probeer oplaai, is groter as die &#39;upload_max_filesize&#39; of die &#39;post_max_size&#39; PHP-instellings. Kontak u stelseladministrateur om hierdie limiete te verhoog.");
?>
